@@ -1,15 +1,16 @@
 #' Run All TAF Scripts
 #'
-#' Run all TAF scripts found in a directory.
+#' Run core TAF scripts in current directory.
 #'
-#' @param path directory containing TAF scripts.
 #' @param \dots passed to \code{\link{sourceTAF}}.
 #'
 #' @return Logical vector, indicating which scripts ran without errors.
 #'
 #' @note
-#' TAF scripts that will be run if they exist: \code{data.R}, \code{input.R},
-#' \code{model.R}, \code{output.R}, and \code{report.R}.
+#' TAF scripts that will be run if they exist: \verb{data.R}, \verb{input.R},
+#' \verb{model.R}, \verb{output.R}, and \verb{report.R}.
+#'
+#' If a \verb{begin.R} script exists, it is ignored.
 #'
 #' @seealso
 #' \code{\link{sourceTAF}} runs a TAF script.
@@ -27,11 +28,8 @@
 #'
 #' @export
 
-sourceAll <- function(path=".", ...)
+sourceAll <- function(...)
 {
-  owd <- setwd(path)
-  on.exit(setwd(owd))
-
   scripts <- c("data.R", "input.R", "model.R", "output.R", "report.R")
   scripts <- scripts[file.exists(scripts)]
 
