@@ -5,26 +5,30 @@
 #' @param script script filename.
 #' @param rm whether to remove all objects from the global environment before
 #'        and after the script is run.
-#' @param clean whether to remove the corresponding TAF directory before running
-#'        the script.
+#' @param clean whether to remove the target directory before running the
+#'        script.
 #' @param quiet whether to suppress messages reporting progress.
 #'
 #' @details
 #' The default value of \code{rm = FALSE} is to protect users from accidental
 #' loss of work, but the TAF server always runs with \code{rm = TRUE} to make
-#' sure that only files, not objects, are carried over between scripts. The
-#' default \code{clean = TRUE} makes sure that the script starts by creating a
-#' new empty directory.
+#' sure that only files, not objects, are carried over between scripts.
+#'
+#' Likewise, the TAF server runs with \code{clean = TRUE} to make sure that the
+#' script starts by creating a new empty directory. The target directory of a
+#' TAF script has the same filename prefix as the script: \verb{data.R} creates
+#' \file{data} etc. An important exception is that a directory called
+#' \file{begin} will never be deleted.
 #'
 #' @return
 #' \code{TRUE} or \code{FALSE}, indicating whether the script ran without
 #' errors.
 #'
 #' @note
-#' Commands within a script may change the working directory, but
-#' \code{sourceTAF} guarantees that after running a script, the working
-#' directory reported by \code{getwd()} is the same before and after running a
-#' script.
+#' Commands within a script (such as \code{setwd}) may change the working
+#' directory, but \code{sourceTAF} guarantees that after running a script, the
+#' working directory reported by \code{getwd()} is the same before and after
+#' running a script.
 #'
 #' @seealso
 #' \code{\link{source}} is the base function to run R scripts.
@@ -51,7 +55,7 @@ sourceTAF <- function(script, rm=FALSE, clean=TRUE, quiet=FALSE)
 {
   if(rm)
     rm(list=ls(.GlobalEnv), pos=.GlobalEnv)
-  if(clean && dir.exists(file_path_sans_ext(script)))
+  if(clean && dir.exists(file_path_sans_ext(script)) && script!="begin.R")
     unlink(file_path_sans_ext(script), recursive=TRUE)
   if(!quiet)
     msg(script, " running...")
